import 'package:fl_chart/fl_chart.dart';
import 'package:flutter/material.dart';
import 'package:og1_chart/src/enums/_enums.dart';
import 'package:og1_chart/src/models/_models.dart';
import 'package:og1_chart/src/services/_services.dart';

class Og1LineChart extends StatefulWidget {
  final ChartLine mainLine;
  final List<ChartLine>? additionalLines;
  final XAxisEnum xAxisEnum;
  final Color? backgroundColor;
  final Color? titleColor;
  final String? yAxisMetric;
  final double? xTitlesFontSize;
  final double? yTitlesFontSize;
  final double? xInterval;
  final double? yInterval;

  const Og1LineChart({
    Key? key,
    required this.mainLine,
    this.additionalLines,
    required this.xAxisEnum,
    this.backgroundColor,
    this.titleColor,
    this.yAxisMetric,
    this.xTitlesFontSize,
    this.yTitlesFontSize,
    this.xInterval,
    this.yInterval,
  }) : super(key: key);

  @override
  _Og1LineChartState createState() => _Og1LineChartState();
}

class _Og1LineChartState extends State<Og1LineChart> {
  late LineChartData lineChartData;

  @override
  void initState() {
    super.initState();
    Og1LineChartService og1LineChartService = Og1LineChartService();
    Og1LineChartDataService og1LineChartDataService = Og1LineChartDataService();
    LineChartBarData mainLineChartBarData = og1LineChartService
        .createLineChartBarData(widget.mainLine, widget.xAxisEnum);
    List<LineChartBarData> additionalLinesChartBarData =
        widget.additionalLines != null
            ? widget.additionalLines!
                .map((additionalLine) => og1LineChartService
                    .createLineChartBarData(additionalLine, widget.xAxisEnum))
                .toList()
            : [];

    lineChartData = og1LineChartDataService.lineChartData(
        backgroundColor: widget.backgroundColor,
        lineBarsData: [mainLineChartBarData, ...additionalLinesChartBarData],
        titlesData: og1LineChartService.createTitlesData(
            widget.yAxisMetric,
            widget.titleColor,
            widget.xTitlesFontSize,
            widget.yTitlesFontSize,
            widget.xInterval,
            widget.yInterval),
        maxX: og1LineChartService.maxX(widget.xAxisEnum),
        maxY: og1LineChartService
                .maxY([mainLineChartBarData, ...additionalLinesChartBarData]) +
            20);
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
        padding: const EdgeInsets.only(top: 30, right: 50),
        child: LineChart(lineChartData));
  }
}
